@@ -1,6 +1,9 @@
 import unittest
 import os
+import tempfile
 
+
+from zipfile import BadZipfile
 from bs4 import BeautifulSoup
 
 from ..dwca import DwCAReader, GBIFResultsReader, DwCALine
@@ -103,8 +106,22 @@ class TestDwCAReader(unittest.TestCase):
     MULTIEXTENSIONS_ARCHIVE_PATH = _sample_data_path('dwca-2extensions.zip')
     UTF8EOL_ARCHIVE_PATH = _sample_data_path('dwca-utf8-eol-test.zip')
 
-    def test_cleanup(self):
-        """Test no temporary files are left after execution"""
+    def test_absolute_temporary_path(self):
+        """Test the absolute_temporary_path() method."""
+        with DwCAReader(self.BASIC_ARCHIVE_PATH) as dwca:
+            path_to_occ = dwca.absolute_temporary_path('occurrence.txt')
+            
+            # Is it absolute ?
+            self.assertTrue(os.path.isabs(path_to_occ))
+            # Does file exists ?
+            self.assertTrue(os.path.isfile(path_to_occ))
+            # IS it the correct content ?
+            f = open(path_to_occ)
+            content = f.read()
+            self.assertTrue(content.startswith("id"))
+
+    def test_auto_cleanup(self):
+        """Test no temporary files are left after execution (using 'with' statement)."""
         num_files_before = len(os.listdir('.'))
 
         with DwCAReader(self.BASIC_ARCHIVE_PATH):
@@ -114,6 +131,18 @@ class TestDwCAReader(unittest.TestCase):
 
         self.assertEqual(num_files_before, num_files_after)
 
+    def test_manual_cleanup(self):
+        """Test no temporary files are left after execution (calling close() manually)."""
+
+        num_files_before = len(os.listdir('.'))
+
+        r = DwCAReader(self.BASIC_ARCHIVE_PATH)
+        r.close()
+
+        num_files_after = len(os.listdir('.'))
+
+        self.assertEqual(num_files_before, num_files_after)
+
     def test_temporary_folder(self):
         """Test a temporary folder is created during execution
 
@@ -408,6 +437,14 @@ class TestDwCAReader(unittest.TestCase):
 
             self.assertEqual(fields, star_dwca.core_terms)
 
+    def test_not_zipfile(self):
+        """ Ensure BadZipfile is raised when passed archive is not  a zip file."""
+        invalid_origin_file = tempfile.NamedTemporaryFile()
+
+        with self.assertRaises(BadZipfile):
+            with DwCAReader(invalid_origin_file.name):
+                pass
+
 
 if __name__ == "__main__":
     unittest.main()
